API docs for “spamfighter.core.firewall.FirewallResult”

# Class s.c.f.FirewallResult(Exception):

Part of spamfighter.core.firewall View Source View In Hierarchy

Служебное исключение, обработка цепочки правил закончилась результатом.

Instance Variables | result | результат обработки (type: `str` )

Method | __init__ | Конструктор.
Method | __str__ | Undocumented

def __init__(self, result): (source)
Конструктор.

def __str__(self): (source)
Undocumented